<?php
/*
 * FlickrShow MediaWiki extension  version 1.01
 *	depend on Galleria + Flickr Plugin http://galleria.io/docs/plugins/flickr/
 *	for details please see: http://kimagurenote.net/kn/FlickrShow#Codes
 *
 * Copyright (c) 2014 KimagureNote http://kimagurenote.net/
 * License: Revised BSD license http://opensource.org/licenses/BSD-3-Clause
 *
 * Usage:
 *	<flickrshow set="photoset_id">(options)</flickrshow>
 *	<flickrshow search="keyword">(options)</flickrshow>
 * Params:
 *	set:	(string) Album (photoset) ID
 *	search:	(string) Keyword
 *	width:	(string) Gallery width (default 100%)
 *	height:	(string) Gallery height (default 450px)
 *	background:	(string) Gallery background style (default #000)
 * Options:
 *	Galleria.run() Options. see: http://galleria.io/docs/options/
 *
 * History:
 * 2014.10.23	v1.01
 *	change $wgFlickrShowGalleria['Dir'] to $wgFlickrShowGalleria['Path']
 *	add $wgFlickrShowGalleria['Size'] support (default '.min')
 *	add $wgFlickrShow['Style'] support (not recommended)
 *	add $wgFlickrShow['Script'] support (not recommended)
 *	add $wgFlickrShow['jQuery'] support
 *	change license to Revised BSD from CC BY-SA 3.0 Unported
 * 2014.10.14	v1.00
 *	1st version.
 *
 */

if( !defined( 'MEDIAWIKI' ) ) {
	echo( "This file is an extension to the MediaWiki software and cannot be used standalone.\n" );
	die( 1 );
}

$wgExtensionCredits['parserhook'][] = array(
	'path'           => __FILE__,
	'name'           => 'FlickrShow',
	'author'         => '[http://kimagurenote.net/ KimagureNote]',
	'url'            => 'http://kimagurenote.net/kn/FlickrShow',
	'version'        => '1.01',
	'license-name'   => 'BSD',
	'descriptionmsg' => 'flickrshow-desc',
);

$wgMessagesDirs['FlickrShow'] = __DIR__ . '/i18n';
$wgExtensionMessagesFiles['FlickrShow'] =  dirname(__FILE__) . '/FlickrShow.i18n.php';

$wgHooks['ParserFirstCallInit'][] = 'wfFlickrShowSetHook';

function wfFlickrShowSetHook( $parser ) {
	$parser->setHook( 'flickrshow', 'wfRenderFlickrShow' );
	return true;
}

/* The callback function for embed Galleria tags */
function wfRenderFlickrShow( $param, $argv, $parser ) {
	global $wgFlickrShow, $wgFlickrShowGalleria;

	$divid = $argv['id'] ? htmlentities($argv['id']) : "flickrshow";
	$divwidth = $argv['width'] ? htmlentities($argv['width']) : "100%";
	$divheight = $argv['height'] ? htmlentities($argv['height']) : "450px";
	$divbg = $argv['background'] ? htmlentities($argv['background']) : "#000";
	$gdir = isset($wgFlickrShowGalleria['Path']) ? $wgFlickrShowGalleria['Path'] : ($wgFlickrShowGalleria['Dir'] ? $wgFlickrShowGalleria['Dir'] : "/galleria");
	$gver = $wgFlickrShowGalleria['Ver'] ? $wgFlickrShowGalleria['Ver'] : "1.4";
	$gsize = isset($wgFlickrShowGalleria['Size']) ? $wgFlickrShowGalleria['Size'] : '.min';
	$gtheme = $wgFlickrShowGalleria['Theme'] ? $wgFlickrShowGalleria['Theme'] : "classic";
	$jquery = isset($wgFlickrShow['jQuery']) ? $wgFlickrShow['jQuery'] : "http://ajax.googleapis.com/ajax/libs/jquery/1/jquery.js";

	$options_json = json_decode('{ ' . $param . ' }', true);

	if($wgFlickrShow['Style']) {
		$output = "<style>\n" . $wgFlickrShow['Style'] . "\n</style>\n";
	} else {
		$output = "";
	}

	$output .= <<<END
<script src="$jquery"></script>
<script src="$gdir/galleria-$gver$gsize.js"></script>
<script src="$gdir/plugins/flickr/galleria.flickr$gsize.js"></script>

<!-- FlickrShow in -->
<div id="$divid" style="width: $divwidth; height: $divheight; background: $divbg;"></div>
<script>
	Galleria.loadTheme('$gdir/themes/$gtheme/galleria.$gtheme$gsize.js');

END;
	$output .= "\tGalleria.run('#" . $divid . "', ";
	if( $argv['set'] ) {
		$options_json['flickr'] = "set:" . htmlentities($argv['set']);
	} elseif( $argv['search'] ) {
		$options_json['flickr'] = "search:" . htmlentities($argv['search']);
	}
	$output .= json_encode($options_json, JSON_UNESCAPED_UNICODE) . "\n);\n";

	if($wgFlickrShow['Script']) {
		$output .= "\t" . $wgFlickrShow['Script'] . "\n";
	}

	$output .= <<<END
</script>
<!-- FlickrShow out -->
END;

	/* for debug
	$dbg = htmlentities($output);
	$output .= "<!-- Debug -->\n<pre>\n$dbg\n";
	$output .= "***\n\$param = { $param }";
	$output .= "\n</pre>\n<!-- /Debug -->\n";
	*/

	return $output;
}
?>
